@@ -6,6 +6,7 @@ import socket
 import struct
 from typing import List, Optional
 
+from pyplumio.const import BYTE_UNDEFINED
 from pyplumio.helpers.typing import ParameterDataType
 
 unpack_float = struct.Struct("<f").unpack
@@ -58,7 +59,7 @@ def unpack_parameter(
 
 def check_parameter(data: bytearray) -> bool:
     """Check if parameter contains any bytes besides 0xFF."""
-    return any(x for x in data if x != 0xFF)
+    return any(x for x in data if x != BYTE_UNDEFINED)
 
 
 def ip4_to_bytes(address: str) -> bytes:
